<?php
/**
 * Custom header implementation
 *
 * @link https://codex.wordpress.org/Custom_Headers
 *
 * @package Short News
 * @since Short News 1.0
 *
 */


/**
* Set up the WordPress Custom Header Feature.
*
* @uses type_header_style()
*/
function short_news_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'short_news_custom_header_args', array(
		'height'				=> 900,
		'width'					=> 1600,
		'flex-width'			=> true,
		'flex-height'			=> true,
		'default-text-color'	=> '111111',
		'default-image'			=> '',
		'wp-head-callback'		=> 'short_news_header_style',
	) ) );
}
add_action( 'after_setup_theme', 'short_news_custom_header_setup' );


if ( ! function_exists( 'short_news_header_style' ) ) :
/**
* Styles the header image and text displayed on the blog.
*/
function short_news_header_style() {
	$header_text_color = get_header_textcolor();

	/*
	 * If no custom options for text are set, let's bail.
	 * get_header_textcolor() options: Any hex value, 'blank' to hide text. Default: add_theme_support( 'custom-header' ).
	 */
	if ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color ) {
		return;
	}

	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( ! display_header_text() ) :
	?>
		.site-title,
		.site-description {
			position: absolute;
			clip: rect(1px, 1px, 1px, 1px);
		}
	<?php
		// If the user has set a custom color for the text use that.
		else :
	?>
		.site-title a, .site-title a:hover {
			color: #<?php echo esc_attr( $header_text_color ); ?>;
		}
	<?php endif; ?>
	</style>
	<?php
}
endif;
